@@ -25,6 +25,9 @@ SCROLL_DOWN = "D"
 CURSOR_UP, CURSOR_DOWN, CURSOR_FORWARD, CURSOR_BACK = ["[%s" for char in 'ABCD']
 ERASE_REST_OF_LINE = "[K"
 ERASE_LINE = "[2K"
+HIDE_CURSOR = "[?25l"
+SHOW_CURSOR = "[?25h"
+ERASE_REST_OF_SCREEN = "[0J"
 
 CURSES_TABLE = {}
 CURSES_TABLE['\x1b[15~'] = 'KEY_F(5)'
@@ -52,8 +55,8 @@ def produce_simple_sequence(seq):
 
 def produce_cursor_sequence(char):
     """Returns a method that issues a cursor control sequence."""
-    def func(self, n=1):
-        if n: self.out_stream.write("[%d%s" % (n, char))
+    def func(ts, n=1):
+        if n: ts.write("[%d%s" % (n, char))
     return func
 
 class TerminalController(object):
@@ -64,15 +67,15 @@ class TerminalController(object):
         self.out_stream = out_stream
         self.in_buffer = []
         self.sigwinch_counter = _SIGWINCH_COUNTER - 1
+        self.last_screen_size = None
 
     def __enter__(self):
         def signal_handler(signum, frame):
             global _SIGWINCH_COUNTER
             _SIGWINCH_COUNTER += 1
+            self.last_screen_size = None
         signal.signal(signal.SIGWINCH, signal_handler)
 
-        #TODO implement this with termios/tty instead of subprocess
-        #self.original_stty = subprocess.check_output(['stty', '-g'])
         self.original_stty = termios.tcgetattr(self.out_stream)
         tty.setraw(self.in_stream)
         return self
@@ -88,6 +91,9 @@ class TerminalController(object):
     scroll_down = produce_simple_sequence(SCROLL_DOWN)
     erase_rest_of_line = produce_simple_sequence(ERASE_REST_OF_LINE)
     erase_line = produce_simple_sequence(ERASE_LINE)
+    hide_cursor = produce_simple_sequence(HIDE_CURSOR)
+    show_cursor = produce_simple_sequence(SHOW_CURSOR)
+    erase_rest_of_screen = produce_simple_sequence(ERASE_REST_OF_SCREEN)
 
     def get_event_curses(self):
         """get event, with keypress events translated to their curses equivalent"""
@@ -96,7 +102,7 @@ class TerminalController(object):
             return CURSES_TABLE[e]
         return e
 
-    def get_event(self, use_curses_aliases=True):
+    def get_event(self, use_curses_aliases=True, fake_input=None):
         """Blocks and returns the next event"""
         #TODO make this cooler - generator? Trie?
         chars = []
@@ -113,6 +119,8 @@ class TerminalController(object):
             (len(chars) == 4 and chars[1] == '\x1b' and chars[2] == '[') or
             (len(chars) > 2 and chars[1] in ['[', 'O'] and chars[-1] not in tuple('1234567890;'))):
                 return ''.join(chars) if not use_curses_aliases else CURSES_TABLE.get(''.join(chars), ''.join(chars))
+            if fake_input:
+                self.in_buffer.extend(list(fake_input))
             if self.in_buffer:
                 chars.append(self.in_buffer.pop(0))
                 continue
@@ -148,15 +156,18 @@ class TerminalController(object):
 
     def set_cursor_position(self, xxx_todo_changeme):
         (row, col) = xxx_todo_changeme
-        self.out_stream.write("[%d;%dH" % (row, col))
+        self.write("[%d;%dH" % (row, col))
 
-    def get_screen_size(self):
+    def get_screen_size(self, break_cache=False):
         #TODO generalize get_cursor_position code and use it here instead
+        if self.last_screen_size and not break_cache:
+            return self.last_screen_size
         orig = self.get_cursor_position()
         self.fwd(10000) # 10000 is much larger than any reasonable terminal
         self.down(10000)
         size = self.get_cursor_position()
         self.set_cursor_position(orig)
+        self.last_screen_size = size
         return size
 
 def test():
